@@ -27,7 +27,7 @@
 
 class KFader : public TQSlider
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	protected:
 		void init();
