@@ -68,7 +68,7 @@ class TDEPopupMenu;
 class TDEAction;
 
 class KVolumeFader_Widget : public TQFrame {
-   Q_OBJECT
+   TQ_OBJECT
   
 private:
 	KVolumeFader_impl* _impl;
