@@ -39,10 +39,10 @@ DirectoryList::DirectoryList(const TQStringList &directories, bool importPlaylis
 
     m_base->directoryListView->setFullWidth(true);
 
-    connect(m_base->addDirectoryButton, TQT_SIGNAL(clicked()),
-        TQT_SLOT(slotAddDirectory()));
-    connect(m_base->removeDirectoryButton, TQT_SIGNAL(clicked()),
-        TQT_SLOT(slotRemoveDirectory()));
+    connect(m_base->addDirectoryButton, TQ_SIGNAL(clicked()),
+        TQ_SLOT(slotAddDirectory()));
+    connect(m_base->removeDirectoryButton, TQ_SIGNAL(clicked()),
+        TQ_SLOT(slotRemoveDirectory()));
 
     TQStringList::ConstIterator it = directories.begin();
     for(; it != directories.end(); ++it)
