@@ -58,80 +58,80 @@ KAudioCreator::KAudioCreator( TQWidget* parent, const char* name) :
     TQVBox *frame = janusWidget->addVBoxPage(i18n("&CD Tracks"), TQString(), SmallIcon("media-optical-cdaudio-unmounted", 32));
     tracks = new TracksImp(frame, "Tracks");
 
-    ripper  = new Ripper ( TQT_TQOBJECT(frame), "Rip" );
-    encoder = new Encoder( TQT_TQOBJECT(frame), "Encoder" );
+    ripper  = new Ripper ( frame, "Rip" );
+    encoder = new Encoder( frame, "Encoder" );
 
     frame = janusWidget->addVBoxPage( i18n("&Jobs"), TQString(), SmallIcon( "system-run", 32 ) );
     jobQue = new JobQueImp( frame, "Que" );
 
     resize(500, 440);
 
-    /*TDEAction *eject = */new TDEAction( i18n("&Eject CD"), 0, TQT_TQOBJECT(tracks),
-                                  TQT_SLOT( eject() ), actionCollection(), "eject" );
+    /*TDEAction *eject = */new TDEAction( i18n("&Eject CD"), 0, tracks,
+                                  TQ_SLOT( eject() ), actionCollection(), "eject" );
 
-    (void)new TDEAction( i18n("&Configure KAudioCreator..."), 0, TQT_TQOBJECT(this),
-                       TQT_SLOT( showSettings() ), actionCollection(), "configure_kaudiocreator" );
+    (void)new TDEAction( i18n("&Configure KAudioCreator..."), 0, this,
+                       TQ_SLOT( showSettings() ), actionCollection(), "configure_kaudiocreator" );
 
-    TDEAction *selectAll   = new TDEAction( i18n( "Select &All Tracks"), 0, TQT_TQOBJECT(tracks),
-                                        TQT_SLOT( selectAllTracks()   ), actionCollection(), "select_all" ) ;
-    TDEAction *deselectAll = new TDEAction( i18n( "Deselect &All Tracks"), 0, TQT_TQOBJECT(tracks),
-                                        TQT_SLOT( deselectAllTracks() ), actionCollection(), "deselect_all" );
+    TDEAction *selectAll   = new TDEAction( i18n( "Select &All Tracks"), 0, tracks,
+                                        TQ_SLOT( selectAllTracks()   ), actionCollection(), "select_all" ) ;
+    TDEAction *deselectAll = new TDEAction( i18n( "Deselect &All Tracks"), 0, tracks,
+                                        TQ_SLOT( deselectAllTracks() ), actionCollection(), "deselect_all" );
     selectAll->setEnabled( false );
     deselectAll->setEnabled( false );
 
     TDEActionMenu *actActionMenu = new TDEActionMenu( i18n("Rip &Selection"), "rip", actionCollection(), "rip" );
     actActionMenu->setDelayed(true); //needed for checking "all accounts"
     actActionMenu->setEnabled( false );   
-    connect( actActionMenu, TQT_SIGNAL( activated() ), TQT_TQOBJECT(tracks), TQT_SLOT( startSession() ) );
+    connect( actActionMenu, TQ_SIGNAL( activated() ), tracks, TQ_SLOT( startSession() ) );
 
     ripMenu = actActionMenu->popupMenu();
-    connect( ripMenu, TQT_SIGNAL( activated(int) ), TQT_TQOBJECT(this), TQT_SLOT( slotRipSelection(int)) );
-    connect( ripMenu, TQT_SIGNAL( aboutToShow() ), TQT_TQOBJECT(this), TQT_SLOT( getRipMenu()) );
+    connect( ripMenu, TQ_SIGNAL( activated(int) ), this, TQ_SLOT( slotRipSelection(int)) );
+    connect( ripMenu, TQ_SIGNAL( aboutToShow() ), this, TQ_SLOT( getRipMenu()) );
 
-    TDEAction *rip = new TDEAction( i18n( "Rip &Selection" ), 0, TQT_TQOBJECT(tracks),
-                                TQT_SLOT( startSession() ), actionCollection(), "rip_selected" );
+    TDEAction *rip = new TDEAction( i18n( "Rip &Selection" ), 0, tracks,
+                                TQ_SLOT( startSession() ), actionCollection(), "rip_selected" );
     rip->setEnabled( false );
 
-    connect( jobQue, TQT_SIGNAL( removeJob(int) ), TQT_TQOBJECT(this),    TQT_SLOT( updateStatus() ) );
-    connect( jobQue, TQT_SIGNAL( removeJob(int) ), TQT_TQOBJECT(ripper), TQT_SLOT( removeJob(int) ) );
-    connect( jobQue, TQT_SIGNAL( removeJob(int) ), TQT_TQOBJECT(encoder), TQT_SLOT( removeJob(int)) );
+    connect( jobQue, TQ_SIGNAL( removeJob(int) ), this,    TQ_SLOT( updateStatus() ) );
+    connect( jobQue, TQ_SIGNAL( removeJob(int) ), ripper, TQ_SLOT( removeJob(int) ) );
+    connect( jobQue, TQ_SIGNAL( removeJob(int) ), encoder, TQ_SLOT( removeJob(int)) );
 
-    connect( ripper, TQT_SIGNAL( updateProgress(int, int) ), TQT_TQOBJECT(jobQue), TQT_SLOT( updateProgress(int,int) ) );
-    connect( ripper, TQT_SIGNAL( addJob(Job*, const TQString &) ), TQT_TQOBJECT(jobQue),  TQT_SLOT( addJob(Job*, const TQString &)) );
-    connect( ripper, TQT_SIGNAL( eject(const TQString &) )       , TQT_TQOBJECT(tracks),  TQT_SLOT( ejectDevice(const TQString &)) );
-    connect( ripper, TQT_SIGNAL( encodeWav(Job *) )             , TQT_TQOBJECT(encoder), TQT_SLOT( encodeWav(Job *)) );
-    connect( ripper, TQT_SIGNAL( jobsChanged() )                , TQT_TQOBJECT(this),    TQT_SLOT( updateStatus() ) );   
+    connect( ripper, TQ_SIGNAL( updateProgress(int, int) ), jobQue, TQ_SLOT( updateProgress(int,int) ) );
+    connect( ripper, TQ_SIGNAL( addJob(Job*, const TQString &) ), jobQue,  TQ_SLOT( addJob(Job*, const TQString &)) );
+    connect( ripper, TQ_SIGNAL( eject(const TQString &) )       , tracks,  TQ_SLOT( ejectDevice(const TQString &)) );
+    connect( ripper, TQ_SIGNAL( encodeWav(Job *) )             , encoder, TQ_SLOT( encodeWav(Job *)) );
+    connect( ripper, TQ_SIGNAL( jobsChanged() )                , this,    TQ_SLOT( updateStatus() ) );   
 
-    connect( encoder, TQT_SIGNAL( updateProgress(int, int) )   , TQT_TQOBJECT(jobQue),  TQT_SLOT( updateProgress(int,int)) );
-    connect( encoder, TQT_SIGNAL( addJob(Job*, const TQString&)), TQT_TQOBJECT(jobQue),  TQT_SLOT( addJob(Job*, const TQString &)) );
-    connect( encoder, TQT_SIGNAL( jobsChanged() )              , TQT_TQOBJECT(this),    TQT_SLOT( updateStatus() ) );
+    connect( encoder, TQ_SIGNAL( updateProgress(int, int) )   , jobQue,  TQ_SLOT( updateProgress(int,int)) );
+    connect( encoder, TQ_SIGNAL( addJob(Job*, const TQString&)), jobQue,  TQ_SLOT( addJob(Job*, const TQString &)) );
+    connect( encoder, TQ_SIGNAL( jobsChanged() )              , this,    TQ_SLOT( updateStatus() ) );
 
-    connect( tracks, TQT_SIGNAL( hasCD(bool) )    , TQT_TQOBJECT(this),          TQT_SLOT( hasCD(bool) ) );
-    connect( tracks, TQT_SIGNAL( ripTrack(Job *) ), TQT_TQOBJECT(ripper),       TQT_SLOT( ripTrack(Job *)) );
-    connect( tracks, TQT_SIGNAL( hasTracks(bool) ), rip,           TQT_SLOT( setEnabled(bool)) );
-    connect( tracks, TQT_SIGNAL( hasTracks(bool) ), actActionMenu, TQT_SLOT( setEnabled(bool)) );
-    connect( tracks, TQT_SIGNAL( hasTracks(bool) ), deselectAll,   TQT_SLOT( setEnabled(bool)) );
-    connect( tracks, TQT_SIGNAL( hasTracks(bool) ), selectAll,     TQT_SLOT( setEnabled(bool)) );
+    connect( tracks, TQ_SIGNAL( hasCD(bool) )    , this,          TQ_SLOT( hasCD(bool) ) );
+    connect( tracks, TQ_SIGNAL( ripTrack(Job *) ), ripper,       TQ_SLOT( ripTrack(Job *)) );
+    connect( tracks, TQ_SIGNAL( hasTracks(bool) ), rip,           TQ_SLOT( setEnabled(bool)) );
+    connect( tracks, TQ_SIGNAL( hasTracks(bool) ), actActionMenu, TQ_SLOT( setEnabled(bool)) );
+    connect( tracks, TQ_SIGNAL( hasTracks(bool) ), deselectAll,   TQ_SLOT( setEnabled(bool)) );
+    connect( tracks, TQ_SIGNAL( hasTracks(bool) ), selectAll,     TQ_SLOT( setEnabled(bool)) );
 
-    (void)new TDEAction(i18n("Remove &Completed Jobs"), 0, TQT_TQOBJECT(jobQue),
-          TQT_SLOT(clearDoneJobs()), actionCollection(), "clear_done_jobs" );
+    (void)new TDEAction(i18n("Remove &Completed Jobs"), 0, jobQue,
+          TQ_SLOT(clearDoneJobs()), actionCollection(), "clear_done_jobs" );
 
-    TDEAction *edit = new TDEAction(i18n("&Edit Album..."), 0, TQT_TQOBJECT(tracks),
-          TQT_SLOT(editInformation()), actionCollection(), "edit_cd");
-    connect(tracks, TQT_SIGNAL(hasCD(bool)), edit, TQT_SLOT(setEnabled(bool)));
+    TDEAction *edit = new TDEAction(i18n("&Edit Album..."), 0, tracks,
+          TQ_SLOT(editInformation()), actionCollection(), "edit_cd");
+    connect(tracks, TQ_SIGNAL(hasCD(bool)), edit, TQ_SLOT(setEnabled(bool)));
     edit->setEnabled( false );
 
-    (void)new TDEAction(i18n("Encode &File..."), 0, TQT_TQOBJECT(this),
-          TQT_SLOT(encodeFile()), actionCollection(), "encode_file");
+    (void)new TDEAction(i18n("Encode &File..."), 0, this,
+          TQ_SLOT(encodeFile()), actionCollection(), "encode_file");
 
-    TDEAction *cddb = new TDEAction(i18n("&CDDB Lookup"), 0, TQT_TQOBJECT(tracks),
-          TQT_SLOT(performCDDB()), actionCollection(), "cddb_now");
-    connect(tracks, TQT_SIGNAL(hasCD(bool)), cddb, TQT_SLOT(setEnabled(bool)));
+    TDEAction *cddb = new TDEAction(i18n("&CDDB Lookup"), 0, tracks,
+          TQ_SLOT(performCDDB()), actionCollection(), "cddb_now");
+    connect(tracks, TQ_SIGNAL(hasCD(bool)), cddb, TQ_SLOT(setEnabled(bool)));
     cddb->setEnabled( false );
 
-    KStdAction::configureNotifications(TQT_TQOBJECT(this), TQT_SLOT(configureNotifications()),
+    KStdAction::configureNotifications(this, TQ_SLOT(configureNotifications()),
           actionCollection());
-    KStdAction::quit( TQT_TQOBJECT(this), TQT_SLOT(close()), actionCollection(), "quit" );
+    KStdAction::quit( this, TQ_SLOT(close()), actionCollection(), "quit" );
 
     // Init statusbar
     statusBar()->insertItem(i18n("No Audio CD detected"), 0 );
@@ -216,7 +216,7 @@ void KAudioCreator::configureNotifications() {
 
 void KAudioCreator::encodeFile(){
     EncodeFileImp *file = new EncodeFileImp(this, "EncodeFile");
-    connect(file, TQT_SIGNAL(startJob(Job*)),encoder, TQT_SLOT(encodeWav(Job*)));
+    connect(file, TQ_SIGNAL(startJob(Job*)),encoder, TQ_SLOT(encodeWav(Job*)));
     file->show();
 }
 
@@ -228,10 +228,10 @@ void KAudioCreator::showSettings(){
         return;
 
     SettingsDialog *dialog = new SettingsDialog(this, "settings", Prefs::self());
-    connect(dialog, TQT_SIGNAL(settingsChanged()), ripper, TQT_SLOT(loadSettings()));
-    connect(dialog, TQT_SIGNAL(settingsChanged()), TQT_TQOBJECT(encoder), TQT_SLOT(loadSettings()));
-    connect(dialog, TQT_SIGNAL(settingsChanged()), TQT_TQOBJECT(tracks), TQT_SLOT(loadSettings()));
-    connect(dialog->encoderConfigImp, TQT_SIGNAL(encoderUpdated()), TQT_TQOBJECT(encoder), TQT_SLOT(loadSettings()));
+    connect(dialog, TQ_SIGNAL(settingsChanged()), ripper, TQ_SLOT(loadSettings()));
+    connect(dialog, TQ_SIGNAL(settingsChanged()), encoder, TQ_SLOT(loadSettings()));
+    connect(dialog, TQ_SIGNAL(settingsChanged()), tracks, TQ_SLOT(loadSettings()));
+    connect(dialog->encoderConfigImp, TQ_SIGNAL(encoderUpdated()), encoder, TQ_SLOT(loadSettings()));
     dialog->show();
 }
 
@@ -253,7 +253,7 @@ SettingsDialog::SettingsDialog(TQWidget *parent, const char *name,TDEConfigSkele
         {
             cddb->load();
             addPage(cddb, i18n("CDDB"), "media-optical-cdaudio-mounted", i18n("CDDB Configuration"), false);
-            connect(cddb, TQT_SIGNAL(changed(bool)), TQT_TQOBJECT(this), TQT_SLOT(slotCddbChanged(bool)));
+            connect(cddb, TQ_SIGNAL(changed(bool)), this, TQ_SLOT(slotCddbChanged(bool)));
         }
     }
     RipConfig *rip = new RipConfig(0, "Ripper");
