@@ -34,6 +34,7 @@
 #include <tdelocale.h>
 #include <tdepopupmenu.h>
 #include <tdeglobalsettings.h>
+#include <kstandarddirs.h>
 #include <tdemainwindow.h>
 
 #include <tqapplication.h>
@@ -47,6 +48,7 @@
 #include "mixer.h"
 #include "mixdevicewidget.h"
 #include "kmixdockwidget.h"
+#include "kmixsettings.h"
 #include "viewdockareapopup.h"
 
 KMixDockWidget::KMixDockWidget( Mixer *mixer, TQWidget *parent, const char *name, bool volumePopup, bool dockIconMuting )
@@ -71,7 +73,10 @@ KMixDockWidget::KMixDockWidget( Mixer *mixer, TQWidget *parent, const char *name
     }
     createActions();
     createMasterVolWidget();
-    connect(this, TQT_SIGNAL(quitSelected()), kapp, TQT_SLOT(quitExtended()));
+    connect(this, TQ_SIGNAL(quitSelected()), kapp, TQ_SLOT(quitExtended()));
+
+    TDEGlobal::dirs()->addResourceDir("icons_crystal",    locate("appdata", "pics/crystal/"));
+    TDEGlobal::dirs()->addResourceDir("icons_oldcrystal", locate("appdata", "pics/oldcrystal/"));
 }
 
 KMixDockWidget::~KMixDockWidget()
@@ -89,7 +94,7 @@ void KMixDockWidget::createActions()
     TDEPopupMenu *popupMenu = contextMenu();
 
     // Put "Mute" selector in context menu
-    (void)new TDEToggleAction(i18n("M&ute"), 0, TQT_TQOBJECT(this), TQT_SLOT(dockMute()),
+    (void)new TDEToggleAction(i18n("M&ute"), 0, this, TQ_SLOT(dockMute()),
                               actionCollection(), "dock_mute");
     TDEAction *a = actionCollection()->action("dock_mute");
     if (a)
@@ -100,7 +105,7 @@ void KMixDockWidget::createActions()
     // Put "Select Master Channel" dialog in context menu
     if (m_mixer)
     {
-        (void)new TDEAction(i18n("Select Master Channel..."), 0, TQT_TQOBJECT(this), TQT_SLOT(selectMaster()),
+        (void)new TDEAction(i18n("Select Master Channel..."), 0, this, TQ_SLOT(selectMaster()),
                             actionCollection(), "select_master");
         a = actionCollection()->action("select_master");
         if (a)
@@ -178,8 +183,8 @@ void KMixDockWidget::createMasterVolWidget()
      * Refreshing the Icon
      *
      */
-    connect(m_mixer, TQT_SIGNAL(newVolumeLevels()), TQT_TQOBJECT(this), TQT_SLOT(setVolumeTip()));
-    connect(m_mixer, TQT_SIGNAL(newVolumeLevels()), TQT_TQOBJECT(this), TQT_SLOT(slotUpdatePixmap()));
+    connect(m_mixer, TQ_SIGNAL(newVolumeLevels()), this, TQ_SLOT(setVolumeTip()));
+    connect(m_mixer, TQ_SIGNAL(newVolumeLevels()), this, TQ_SLOT(slotUpdatePixmap()));
 }
 
 void KMixDockWidget::deleteMasterVolWidget()
@@ -191,8 +196,8 @@ void KMixDockWidget::deleteMasterVolWidget()
     }
     if (m_mixer)
     {
-        disconnect(m_mixer, TQT_SIGNAL(newVolumeLevels()), TQT_TQOBJECT(this), TQT_SLOT(setVolumeTip()));
-        disconnect(m_mixer, TQT_SIGNAL(newVolumeLevels()), TQT_TQOBJECT(this), TQT_SLOT(slotUpdatePixmap()));
+        disconnect(m_mixer, TQ_SIGNAL(newVolumeLevels()), this, TQ_SLOT(setVolumeTip()));
+        disconnect(m_mixer, TQ_SIGNAL(newVolumeLevels()), this, TQ_SLOT(slotUpdatePixmap()));
     }
 }
 
@@ -206,7 +211,7 @@ void KMixDockWidget::selectMaster()
    if (!_dsm)
    {
        _dsm = new DialogSelectMaster(m_mixer);
-       connect(_dsm, TQT_SIGNAL(newMasterSelected(bool, int, const TQString&)), TQT_SLOT( handleNewMaster(bool, int, const TQString&)));
+       connect(_dsm, TQ_SIGNAL(newMasterSelected(bool, int, const TQString&)), TQ_SLOT( handleNewMaster(bool, int, const TQString&)));
    }
    _dsm->show(m_mixer);
 }
@@ -254,6 +259,20 @@ void KMixDockWidget::handleNewMaster(bool defaultMaster, int soundcard_id, const
 }
 
 
+long
+KMixDockWidget::getAvgVolume()
+{
+    MixDevice *md = 0;
+    if ( _dockAreaPopup != 0 ) {
+        md = _dockAreaPopup->dockDevice();
+    }
+
+    if ( md == 0 || md->maxVolume() == 0 )
+        return -1;
+
+    return (md->getVolume().getAvgVolume(Volume::MMAIN)*100 )/( md->maxVolume() );
+}
+
 void
 KMixDockWidget::setVolumeTip()
 {
@@ -261,6 +280,7 @@ KMixDockWidget::setVolumeTip()
     if ( _dockAreaPopup != 0 ) {
         md = _dockAreaPopup->dockDevice();
     }
+
     TQString tip = "";
 
     int newToolTipValue = 0;
@@ -271,10 +291,7 @@ KMixDockWidget::setVolumeTip()
     }
     else
     {
-        long val = -1;
-        if ( md->maxVolume() != 0 ) {
-	    val = (md->getVolume().getAvgVolume(Volume::MMAIN)*100 )/( md->maxVolume() );
-        }
+        long val = getAvgVolume();
 	newToolTipValue = val + 10000*md->isMuted();
 	if ( _oldToolTipValue != newToolTipValue ) {
 	    tip = i18n( "Volume at %1%" ).arg( val );
@@ -316,7 +333,13 @@ KMixDockWidget::updatePixmap(bool force)
     }
     else
     {
-	newPixmapType = 'd';
+	long avgVol = getAvgVolume();
+	if ( avgVol <= 33 )
+		newPixmapType = 'L';
+	else if ( avgVol <= 67 )
+		newPixmapType = 'M';
+	else
+		newPixmapType = 'H';
     }
 
     if (( newPixmapType != _oldPixmapType ) || (force == true)) {
@@ -325,12 +348,23 @@ KMixDockWidget::updatePixmap(bool force)
 	TQPixmap origpixmap;
 	TQPixmap scaledpixmap;
 	TQImage newIcon;
+
+	TQStringList fallback;
 	switch ( newPixmapType ) {
-		case 'e': origpixmap = isShown() ? loadSizedIcon( "kmixdocked_error", width() ) : loadIcon( "kmixdocked_error"); break;
-		case 'm': origpixmap = isShown() ? loadSizedIcon( "kmixdocked_mute" , width() ) : loadIcon( "kmixdocked_mute"); break;
-		case 'd': origpixmap = isShown() ? loadSizedIcon( "kmixdocked"      , width() ) : loadIcon( "kmixdocked     "); break;
+		case 'm': fallback << "audio-volume-muted"  << "kmixdocked_mute"; break;
+		case 'L': fallback << "audio-volume-low"    << "kmixdocked";	  break;
+		case 'M': fallback << "audio-volume-medium" << "kmixdocked";	  break;
+		case 'H': fallback << "audio-volume-high"   << "kmixdocked";	  break;
 	}
-	newIcon = origpixmap;
+
+	TQString icon = getIconPath(fallback);
+	if (icon.isNull())
+	{
+		icon = getIconPath("audio-volume-error");
+	}
+
+	origpixmap = isShown() ? loadSizedIcon(icon, width()) : loadIcon(icon);
+	newIcon    = origpixmap;
 	if (isShown()) {
 		newIcon = newIcon.smoothScale(width(), height());
 	}
@@ -341,6 +375,51 @@ KMixDockWidget::updatePixmap(bool force)
     }
 }
 
+TQString KMixDockWidget::getIconPath(TQStringList fallback)
+{
+	auto iconTheme = KMixSettings::iconTheme();
+
+	TQCString iconThemeName;
+	if (iconTheme != KMixSettings::EnumIconTheme::System)
+	{
+		switch (iconTheme)
+		{
+			case KMixSettings::EnumIconTheme::OldCrystal:
+				iconThemeName = "oldcrystal";
+				break;
+
+			default:
+			case KMixSettings::EnumIconTheme::Crystal:
+				iconThemeName = "crystal";
+				break;
+		}
+	}
+
+	for (TQStringList::iterator it = fallback.begin(); it != fallback.end(); ++it)
+	{
+		if (iconTheme == KMixSettings::EnumIconTheme::System)
+		{
+			TQString iconPath = kapp->iconLoader()->iconPath((*it), TDEIcon::Panel, true);
+			if (!iconPath.isNull())
+			{
+				return iconPath;
+			}
+		}
+
+		else
+		{
+			TQCString type = "icons_" + iconThemeName;
+
+			TQString iconPath = TDEGlobal::dirs()->findResource(type, TQString("%1.png").arg(*it));
+			if (!iconPath.isNull()) return iconPath;
+
+			iconPath = TDEGlobal::dirs()->findResource(type, TQString("%1.svg").arg(*it));
+			if (!iconPath.isNull()) return iconPath;
+		}
+	}
+	return TQString::null;
+}
+
 void KMixDockWidget::resizeEvent ( TQResizeEvent * )
 {
 	updatePixmap(true);
