@@ -28,7 +28,7 @@ class TQCheckBox;
 class KPushButton;
 
 class KRecConfigGeneral : public TDECModule {
-   Q_OBJECT
+   TQ_OBJECT
   
 public:
 	KRecConfigGeneral( TQWidget*, const char* =0, const TQStringList& = TQStringList() );
