@@ -11,7 +11,7 @@ class CDInfoDialogBase;
 
 class CDDBDlg : public KDialogBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
