@@ -8,7 +8,7 @@ using namespace KCDDB;
 
 class AsyncSMTPSubmitTest : public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
