@@ -22,9 +22,9 @@ extern "C" {
 #include <string.h>
 #include <stdio.h>
 	   }
-#include <kdemacros.h>
+#include <tdemacros.h>
   
-class KDE_EXPORT Buffer {
+class TDE_EXPORT Buffer {
 
   char* msg;
   int nSize;
