@@ -10,7 +10,7 @@ class Lirc;
 
 class InfraRed : public TQObject, public Plugin
 {
-Q_OBJECT
+TQ_OBJECT
   
 NOATUNPLUGIND
 public:
