@@ -26,7 +26,7 @@ class TQLabel;
 
 class KaimanPrefDlg : public CModule
 {
-    Q_OBJECT
+    TQ_OBJECT
   
     public:
 	KaimanPrefDlg( TQObject *parent );
