@@ -160,7 +160,7 @@ void KaimanStyleElement::setPixmap( int num )
         if ( num<0 ) num = 0;
 
         _currentPixmap = num;
-        repaint( FALSE );
+        repaint( false );
     }
 }
 
@@ -646,7 +646,7 @@ KaimanStyleText::KaimanStyleText(TQWidget *parent, const char *name)
     _pos = 0;
     _timer = new TQTimer( this );
     _delay = 500;
-    connect( _timer, TQT_SIGNAL(timeout()), this, TQT_SLOT(timeout()) );
+    connect( _timer, TQ_SIGNAL(timeout()), this, TQ_SLOT(timeout()) );
 }
 
 KaimanStyleText::~KaimanStyleText()
@@ -677,7 +677,7 @@ void KaimanStyleText::startAnimation( int delay )
     _pos = 0;
     _direction = 1;
     _delay = delay;
-    _timer->start( _delay, TRUE );
+    _timer->start( _delay, true );
 }
 
 
@@ -693,7 +693,7 @@ void KaimanStyleText::timeout()
     // reflect
     if ( _pos+_direction<0 || (int)_value.length()-(_pos+_direction)<digits ) {
         _direction = -_direction;
-        _timer->start( _delay*5, TRUE );
+        _timer->start( _delay*5, true );
     } else {
         // check new position
         if ( _pos+_direction>=0 && (int)_value.length()-(_pos+_direction)>=digits ) {
@@ -701,7 +701,7 @@ void KaimanStyleText::timeout()
             repaint();
         }
 
-        _timer->start( _delay, TRUE );
+        _timer->start( _delay, true );
     }
 
 
@@ -741,7 +741,7 @@ KaimanStyleAnimation::KaimanStyleAnimation(int delay, TQWidget *parent, const ch
     _delay = delay;
     _frame = 0;
     _timer = new TQTimer( this );
-    connect( _timer, TQT_SIGNAL(timeout()), this, TQT_SLOT(timeout()) );
+    connect( _timer, TQ_SIGNAL(timeout()), this, TQ_SLOT(timeout()) );
 }
 
 KaimanStyleAnimation::~KaimanStyleAnimation()
@@ -750,7 +750,7 @@ KaimanStyleAnimation::~KaimanStyleAnimation()
 
 void KaimanStyleAnimation::start()
 {
-    _timer->start( _delay, FALSE );
+    _timer->start( _delay, false );
 }
 
 void KaimanStyleAnimation::pause()
@@ -1400,13 +1400,13 @@ bool KaimanStyle::eventFilter( TQObject *o, TQEvent *e )
             TQMouseEvent *m = (TQMouseEvent*)e;
 
             // handle noatun context menu
-            if (m->button()==Qt::RightButton) {
+            if (m->button()==TQt::RightButton) {
                 NoatunStdAction::ContextMenu::showContextMenu();
                 return true;
             }
 
-            TQPoint mousePos( m->x()+TQT_TQWIDGET(o)->x(),
-                             m->y()+TQT_TQWIDGET(o)->y() );
+            TQPoint mousePos( m->x()+static_cast<TQWidget*>(o)->x(),
+                             m->y()+static_cast<TQWidget*>(o)->y() );
             TQWidget *slider = 0;
 
             /* find slider that is under the mouse position */
