@@ -100,9 +100,9 @@ NoatunSystray::NoatunSystray() : TDEMainWindow(0, "NoatunSystray"), Plugin(),
 
 	removeCover(); // make sure any old temp cover is gone
 
-	KStdAction::quit(TQT_TQOBJECT(napp), TQT_SLOT(quit()), actionCollection());
-	KStdAction::open(TQT_TQOBJECT(napp), TQT_SLOT(fileOpen()), actionCollection());
-	KStdAction::preferences(TQT_TQOBJECT(napp), TQT_SLOT(preferences()), actionCollection());
+	KStdAction::quit(napp, TQ_SLOT(quit()), actionCollection());
+	KStdAction::open(napp, TQ_SLOT(fileOpen()), actionCollection());
+	KStdAction::preferences(napp, TQ_SLOT(preferences()), actionCollection());
 	NoatunStdAction::back(actionCollection(), "back");
 	NoatunStdAction::stop(actionCollection(), "stop");
 	NoatunStdAction::playpause(actionCollection(), "play");
@@ -124,11 +124,11 @@ NoatunSystray::NoatunSystray() : TDEMainWindow(0, "NoatunSystray"), Plugin(),
 	showingTrayStatus = false;
 
 	mBlinkTimer = new TQTimer(this);
-	connect(mBlinkTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(slotBlinkTimer()));
+	connect(mBlinkTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(slotBlinkTimer()));
 
-	connect(napp->player(), TQT_SIGNAL(playing()), this, TQT_SLOT(slotPlayPause()));
-	connect(napp->player(), TQT_SIGNAL(paused()), this, TQT_SLOT(slotPlayPause()));
-	connect(napp->player(), TQT_SIGNAL(stopped()), this, TQT_SLOT(slotStopped()));
+	connect(napp->player(), TQ_SIGNAL(playing()), this, TQ_SLOT(slotPlayPause()));
+	connect(napp->player(), TQ_SIGNAL(paused()), this, TQ_SLOT(slotPlayPause()));
+	connect(napp->player(), TQ_SIGNAL(stopped()), this, TQ_SLOT(slotStopped()));
 	//napp->player()->handleButtons();
 }
 
@@ -145,8 +145,8 @@ NoatunSystray::~NoatunSystray()
 
 void NoatunSystray::init()
 {
-	YHModule *cmod = new YHModule(TQT_TQOBJECT(this));
-	connect(cmod, TQT_SIGNAL(saved()), this, TQT_SLOT(slotLoadSettings()));
+	YHModule *cmod = new YHModule(this);
+	connect(cmod, TQ_SIGNAL(saved()), this, TQ_SLOT(slotLoadSettings()));
 	slotLoadSettings();
 }
 
@@ -364,7 +364,7 @@ void NoatunSystray::setTipText(const TQString& text)
 
 	YHConfig *c = YHConfig::self();
 	if(c->passivePopup())
-		TQTimer::singleShot(0, this, TQT_SLOT(showPassivePopup()));
+		TQTimer::singleShot(0, this, TQ_SLOT(showPassivePopup()));
 
 	if(c->tip())
 		TQToolTip::add(mTray, tipText);
@@ -405,11 +405,11 @@ void NoatunSystray::showPassivePopup()
 
 			TQPushButton *forwardButton = new TQPushButton(action("forward")->iconSet(), 0, buttonBox, "popup_forward");
 			forwardButton->setFlat(true);
-			connect(forwardButton, TQT_SIGNAL(clicked()), action("forward"), TQT_SLOT(activate()));
+			connect(forwardButton, TQ_SIGNAL(clicked()), action("forward"), TQ_SLOT(activate()));
 
 			TQPushButton *backButton = new TQPushButton(action("back")->iconSet(), 0, buttonBox, "popup_back");
 			backButton->setFlat(true);
-			connect(backButton, TQT_SIGNAL(clicked()), action("back"), TQT_SLOT(activate()));
+			connect(backButton, TQ_SIGNAL(clicked()), action("back"), TQ_SLOT(activate()));
 
 			TQFrame *line = new TQFrame(box);
 			line->setFrameShape(TQFrame::VLine);
@@ -429,11 +429,11 @@ void NoatunSystray::showPassivePopup()
 
 			TQPushButton *forwardButton = new TQPushButton(action("forward")->iconSet(), 0, buttonBox, "popup_forward");
 			forwardButton->setFlat(true);
-			connect(forwardButton, TQT_SIGNAL(clicked()), action("forward"), TQT_SLOT(activate()));
+			connect(forwardButton, TQ_SIGNAL(clicked()), action("forward"), TQ_SLOT(activate()));
 
 			TQPushButton *backButton = new TQPushButton(action("back")->iconSet(), 0, buttonBox, "popup_back");
 			backButton->setFlat(true);
-			connect(backButton, TQT_SIGNAL(clicked()), action("back"), TQT_SLOT(activate()));
+			connect(backButton, TQ_SIGNAL(clicked()), action("back"), TQ_SLOT(activate()));
 		}
 		mPassivePopup->setView(box);
 	}
