@@ -83,18 +83,18 @@ WaSkin::WaSkin() : TQWidget(0, "NoatunWinampSkin"), UserInterface()
     title_shaded = false;
 
     // These slots make Young Hickory love us
-    connect( napp, TQT_SIGNAL(hideYourself()), this, TQT_SLOT(hide()) );
-    connect( napp, TQT_SIGNAL(showYourself()), this, TQT_SLOT(show()) );
+    connect( napp, TQ_SIGNAL(hideYourself()), this, TQ_SLOT(hide()) );
+    connect( napp, TQ_SIGNAL(showYourself()), this, TQ_SLOT(show()) );
 
-    connect(napp->player(), TQT_SIGNAL(playlistShown()), this,
-            TQT_SLOT(playlistShown()));
-    connect(napp->player(), TQT_SIGNAL(playlistHidden()), this,
-            TQT_SLOT(playlistHidden()));
-    connect(napp->player(), TQT_SIGNAL(loopTypeChange(int)), this,
-            TQT_SLOT(loopChange(int)));
-    connect(napp->player(), TQT_SIGNAL(newSong()), this, TQT_SLOT(newSong()));
+    connect(napp->player(), TQ_SIGNAL(playlistShown()), this,
+            TQ_SLOT(playlistShown()));
+    connect(napp->player(), TQ_SIGNAL(playlistHidden()), this,
+            TQ_SLOT(playlistHidden()));
+    connect(napp->player(), TQ_SIGNAL(loopTypeChange(int)), this,
+            TQ_SLOT(loopChange(int)));
+    connect(napp->player(), TQ_SIGNAL(newSong()), this, TQ_SLOT(newSong()));
 
-    connect(napp->player(), TQT_SIGNAL(timeout()), this, TQT_SLOT(timetick()));
+    connect(napp->player(), TQ_SIGNAL(timeout()), this, TQ_SLOT(timetick()));
     TDEConfig *config=TDEGlobal::config();
 
     config->setGroup("Winskin");
@@ -106,13 +106,13 @@ WaSkin::WaSkin() : TQWidget(0, "NoatunWinampSkin"), UserInterface()
     setIcon(SmallIcon("noatun"));
 
 
-    TQObject::connect(waTitleBar, TQT_SIGNAL(shaded()), this, TQT_SLOT(shadeEvent()));
+    TQObject::connect(waTitleBar, TQ_SIGNAL(shaded()), this, TQ_SLOT(shadeEvent()));
     // connect to players signals - so we can update our display if someone else
     // changes settings...
 
-    connect(napp->player(), TQT_SIGNAL(stopped()), this, TQT_SLOT(slotStopped()));
-    connect(napp->player(), TQT_SIGNAL(playing()), this, TQT_SLOT(slotPlaying()));
-    connect(napp->player(), TQT_SIGNAL(paused()), this, TQT_SLOT(slotPaused()));
+    connect(napp->player(), TQ_SIGNAL(stopped()), this, TQ_SLOT(slotStopped()));
+    connect(napp->player(), TQ_SIGNAL(playing()), this, TQ_SLOT(slotPlaying()));
+    connect(napp->player(), TQ_SIGNAL(paused()), this, TQ_SLOT(slotPaused()));
 
     napp->player()->handleButtons();
 
@@ -126,7 +126,7 @@ WaSkin::WaSkin() : TQWidget(0, "NoatunWinampSkin"), UserInterface()
     newSong();
 
     // HACK: We won't get focus events otherwise
-    setFocusPolicy(TQ_ClickFocus);
+    setFocusPolicy(TQWidget::ClickFocus);
 
     show();
 }
@@ -180,22 +180,22 @@ void WaSkin::createButtons()
     menu = new WaButton(_WA_MAPPING_TITLE_MENU);
     menu->setPixmapUp(_WA_SKIN_TITLE_MENU_NORM);
     menu->setPixmapDown(_WA_SKIN_TITLE_MENU_PRES);
-    connect(menu, TQT_SIGNAL(clicked()), this, TQT_SLOT(menuEvent()));
+    connect(menu, TQ_SIGNAL(clicked()), this, TQ_SLOT(menuEvent()));
 
     minimize = new WaButton(_WA_MAPPING_TITLE_MIN);
     minimize->setPixmapUp(_WA_SKIN_TITLE_MIN_NORM);
     minimize->setPixmapDown(_WA_SKIN_TITLE_MIN_PRES);
-    connect(minimize, TQT_SIGNAL(clicked()), this, TQT_SLOT(minimizeEvent()));
+    connect(minimize, TQ_SIGNAL(clicked()), this, TQ_SLOT(minimizeEvent()));
 
     titleshade = new WaButton(_WA_MAPPING_TITLE_SHADE);
     titleshade->setPixmapUp(_WA_SKIN_TITLE_SHADE_NORM);
     titleshade->setPixmapDown(_WA_SKIN_TITLE_SHADE_PRES);
-    connect(titleshade, TQT_SIGNAL(clicked()), this, TQT_SLOT(shadeEvent()));
+    connect(titleshade, TQ_SIGNAL(clicked()), this, TQ_SLOT(shadeEvent()));
 
     close = new WaButton(_WA_MAPPING_TITLE_CLOSE);
     close->setPixmapUp(_WA_SKIN_TITLE_CLOSE_NORM);
     close->setPixmapDown(_WA_SKIN_TITLE_CLOSE_PRES);
-    connect(close, TQT_SIGNAL(clicked()), this, TQT_SLOT(doClose()));
+    connect(close, TQ_SIGNAL(clicked()), this, TQ_SLOT(doClose()));
 
     shuffle->setTogglable(true);
     shuffle->show();
@@ -203,44 +203,44 @@ void WaSkin::createButtons()
     repeat->setTogglable(true);
     playlist->setTogglable(true);
 
-    connect(shuffle, TQT_SIGNAL(toggleEvent(bool)),
-	    this, TQT_SLOT(shuffleClickedEvent(bool)));
+    connect(shuffle, TQ_SIGNAL(toggleEvent(bool)),
+	    this, TQ_SLOT(shuffleClickedEvent(bool)));
 
-    connect(repeat, TQT_SIGNAL(toggleEvent(bool)),
-	    this, TQT_SLOT(repeatClickedEvent(bool)));
+    connect(repeat, TQ_SIGNAL(toggleEvent(bool)),
+	    this, TQ_SLOT(repeatClickedEvent(bool)));
 
-    connect(playlist, TQT_SIGNAL(toggleEvent(bool)),
-	    this, TQT_SLOT(playlistClickedEvent(bool)));
+    connect(playlist, TQ_SIGNAL(toggleEvent(bool)),
+	    this, TQ_SLOT(playlistClickedEvent(bool)));
 
-    connect(eq, TQT_SIGNAL(clicked()),
-	    this, TQT_SLOT(eqClickedEvent()));
+    connect(eq, TQ_SIGNAL(clicked()),
+	    this, TQ_SLOT(eqClickedEvent()));
 
     prev->setPixmapUp(_WA_SKIN_CBUTTONS_PREV_NORM);
     prev->setPixmapDown(_WA_SKIN_CBUTTONS_PREV_PRES);
-    connect(prev, TQT_SIGNAL(clicked()), napp->player(), TQT_SLOT(back()));
+    connect(prev, TQ_SIGNAL(clicked()), napp->player(), TQ_SLOT(back()));
 
     play->setPixmapUp(_WA_SKIN_CBUTTONS_PLAY_NORM);
     play->setPixmapDown(_WA_SKIN_CBUTTONS_PLAY_PRES);
-    connect(play, TQT_SIGNAL(clicked()), this, TQT_SLOT(playCurrentEvent()));
+    connect(play, TQ_SIGNAL(clicked()), this, TQ_SLOT(playCurrentEvent()));
 
     pause->setPixmapUp(_WA_SKIN_CBUTTONS_PAUSE_NORM);
     pause->setPixmapDown(_WA_SKIN_CBUTTONS_PAUSE_PRES);
-    connect(pause, TQT_SIGNAL(clicked()), this, TQT_SLOT(playPauseEvent()));
+    connect(pause, TQ_SIGNAL(clicked()), this, TQ_SLOT(playPauseEvent()));
 
 
     stop->setPixmapUp(_WA_SKIN_CBUTTONS_STOP_NORM);
     stop->setPixmapDown(_WA_SKIN_CBUTTONS_STOP_PRES);
-    connect(stop, TQT_SIGNAL(clicked()), napp->player(), TQT_SLOT(stop()));
+    connect(stop, TQ_SIGNAL(clicked()), napp->player(), TQ_SLOT(stop()));
 
 
     next->setPixmapUp(_WA_SKIN_CBUTTONS_NEXT_NORM);
     next->setPixmapDown(_WA_SKIN_CBUTTONS_NEXT_PRES);
-    connect(next, TQT_SIGNAL(clicked()), napp->player(), TQT_SLOT(forward()));
+    connect(next, TQ_SIGNAL(clicked()), napp->player(), TQ_SLOT(forward()));
 
 
     eject->setPixmapUp(_WA_SKIN_CBUTTONS_EJECT_NORM);
     eject->setPixmapDown(_WA_SKIN_CBUTTONS_EJECT_PRESS);
-    connect(eject, TQT_SIGNAL(clicked()), napp, TQT_SLOT(fileOpen()));
+    connect(eject, TQ_SIGNAL(clicked()), napp, TQ_SLOT(fileOpen()));
 
     shuffle->setPixmapUp(_WA_SKIN_SHUFREP_SHUFFLE_NOT_SET_NORM);
     shuffle->setPixmapDown(_WA_SKIN_SHUFREP_SHUFFLE_NOT_SET_PRES);
@@ -280,25 +280,25 @@ void WaSkin::createHighLevelElements()
     waVolumeSlider = new WaVolumeSlider();
     waVolumeSlider->buildGui();
 
-    connect(waVolumeSlider, TQT_SIGNAL(volumeSetValue(int)),
-	    this, TQT_SLOT(volumeSetValue(int)));
-    connect(waVolumeSlider, TQT_SIGNAL(sliderPressed()),
-	    this, TQT_SLOT(volumeSliderPressed()));
-    connect(waVolumeSlider, TQT_SIGNAL(sliderReleased()),
-	    this, TQT_SLOT(volumeSliderReleased()));
+    connect(waVolumeSlider, TQ_SIGNAL(volumeSetValue(int)),
+	    this, TQ_SLOT(volumeSetValue(int)));
+    connect(waVolumeSlider, TQ_SIGNAL(sliderPressed()),
+	    this, TQ_SLOT(volumeSliderPressed()));
+    connect(waVolumeSlider, TQ_SIGNAL(sliderReleased()),
+	    this, TQ_SLOT(volumeSliderReleased()));
 
     waBalanceSlider = new WaBalanceSlider();
     waBalanceSlider->buildGui();
 
-    connect(waBalanceSlider, TQT_SIGNAL(balanceSetValue(int)),
-	    this, TQT_SLOT(balanceSetValue(int)));
-    connect(waBalanceSlider, TQT_SIGNAL(sliderPressed()),
-            this, TQT_SLOT(balanceSliderPressed()));
-    connect(waBalanceSlider, TQT_SIGNAL(sliderReleased()),
-            this, TQT_SLOT(balanceSliderReleased()));
+    connect(waBalanceSlider, TQ_SIGNAL(balanceSetValue(int)),
+	    this, TQ_SLOT(balanceSetValue(int)));
+    connect(waBalanceSlider, TQ_SIGNAL(sliderPressed()),
+            this, TQ_SLOT(balanceSliderPressed()));
+    connect(waBalanceSlider, TQ_SIGNAL(sliderReleased()),
+            this, TQ_SLOT(balanceSliderReleased()));
 
     waDigit = new WaDigit();
-    connect(waDigit, TQT_SIGNAL(digitsClicked()), this, TQT_SLOT(digitsClicked()));
+    connect(waDigit, TQ_SIGNAL(digitsClicked()), this, TQ_SLOT(digitsClicked()));
 
     waBPS = new WaLabel(_WA_MAPPING_BPS);
     waFreq = new WaLabel(_WA_MAPPING_FREQ);
@@ -310,13 +310,13 @@ void WaSkin::createHighLevelElements()
     waStereo = new WaIndicator(_WA_MAPPING_MONOSTER_STEREO, _WA_SKIN_MONOSTER_STEREO_TRUE, _WA_SKIN_MONOSTER_STEREO_FALSE);
     waMono = new WaIndicator(_WA_MAPPING_MONOSTER_MONO, _WA_SKIN_MONOSTER_MONO_TRUE, _WA_SKIN_MONOSTER_MONO_FALSE);
 
-    connect(waJumpSlider, TQT_SIGNAL(jump(int)), this, TQT_SLOT(jump(int)));
-    connect(waJumpSlider, TQT_SIGNAL(sliderPressed()),
-	    this, TQT_SLOT(jumpSliderPressed()));
-    connect(waJumpSlider, TQT_SIGNAL(sliderReleased()),
-	    this, TQT_SLOT(jumpSliderReleased()));
-    connect(waJumpSlider, TQT_SIGNAL(valueChanged(int)),
-	    this, TQT_SLOT(jumpValueChanged(int)));
+    connect(waJumpSlider, TQ_SIGNAL(jump(int)), this, TQ_SLOT(jump(int)));
+    connect(waJumpSlider, TQ_SIGNAL(sliderPressed()),
+	    this, TQ_SLOT(jumpSliderPressed()));
+    connect(waJumpSlider, TQ_SIGNAL(sliderReleased()),
+	    this, TQ_SLOT(jumpSliderReleased()));
+    connect(waJumpSlider, TQ_SIGNAL(valueChanged(int)),
+	    this, TQ_SLOT(jumpValueChanged(int)));
 }
 
 
@@ -518,7 +518,7 @@ void WaSkin::doUnload() {
 }
 
 void WaSkin::doClose() {
-    TQTimer::singleShot(0, this, TQT_SLOT(doUnload()));
+    TQTimer::singleShot(0, this, TQ_SLOT(doUnload()));
 }
 
 void WaSkin::dragEnterEvent(TQDragEnterEvent * event)
