@@ -9,7 +9,7 @@ class WaSkinManager;
 class TQSlider;
 
 class WinSkinConfig:public CModule {
-    Q_OBJECT
+    TQ_OBJECT
   
   public:
     WinSkinConfig(TQWidget * parent, WaSkinManager *waManager);
