@@ -30,8 +30,8 @@ extern "C"
 	#include <cdda_paranoia.h>
 	void paranoiaCallback(long, int);
 
-	#include <kdemacros.h>
-	KDE_EXPORT int kdemain(int argc, char ** argv);
+	#include <tdemacros.h>
+	TDE_EXPORT int kdemain(int argc, char ** argv);
 }
 
 #include "audiocd.h"
